
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/ai/backend/test:dist

from setuptools import setup

setup(**{
    'author': 'Lablup Inc. and contributors',
    'classifiers': [
        'Intended Audience :: Developers',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Environment :: No Input/Output (Daemon)',
        'Topic :: Scientific/Engineering',
        'Topic :: Software Development',
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: MIT License',
    ],
    'description': 'Backend.AI Integration Test Suite',
    'entry_points': {
        'backendai_cli_v10': [
            'test = ai.backend.test.cli.__main__:main',
        ],
    },
    'install_requires': (
        'attrs>=24.2',
        'click~=8.1.7',
        'pytest-dependency>=0.6.0',
        'pytest>=8.3.3',
        'types-setuptools',
    ),
    'license': 'MIT',
    'long_description': """# Backend.AI Testing Toolkit

Automated test suites to validate an installation and integration of clients and servers


## How to run CLI-based integration test

If there is no configuration script named `env-tester.sh`, copy it from `sample-env-tester.sh` and check the configuration env.

```console
$ source env-tester.sh
$ backend.ai test run-cli
```

NOTE: The ENV script is parsed with `"^export (\w+)=(.*)$"` regex pattern line by line.
""",
    'long_description_content_type': 'text/markdown',
    'name': 'backend.ai-test',
    'namespace_packages': (
    ),
    'package_data': {
        'ai.backend.test': (
            'VERSION',
            'py.typed',
        ),
    },
    'packages': (
        'ai.backend.test',
        'ai.backend.test.cli',
    ),
    'project_urls': {
        'Documentation': 'https://docs.backend.ai/',
        'Source': 'https://github.com/lablup/backend.ai',
    },
    'python_requires': '>=3.12,<3.13',
    'url': 'https://github.com/lablup/backend.ai',
    'version': """24.09.2
""",
    'zip_safe': False,
})
